@@ -7,12 +7,13 @@ use Log::ger;
 
 use Exporter 'import';
 use Fcntl ':mode';
+use File::chdir;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-29'; # DATE
+our $DATE = '2023-10-30'; # DATE
 our $DIST = 'App-FileSortUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our %SPEC;
 
@@ -33,8 +34,8 @@ our %argspecs_common = (
         schema => ['str*', in=>\@file_types],
         cmdline_aliases => {
             t => {},
-            f => {summary=>'Shortcut for --type=file', is_flag=>1, code=>sub { $_[0]{type} = 'file' }},
-            d => {summary=>'Shortcut for --type=dir' , is_flag=>1, code=>sub { $_[0]{type} = 'dir'  }},
+            f => {summary=>'Shortcut for `--type=file`', is_flag=>1, code=>sub { $_[0]{type} = 'file' }},
+            d => {summary=>'Shortcut for `--type=dir`' , is_flag=>1, code=>sub { $_[0]{type} = 'dir'  }},
         },
         tags => ['category:filtering'],
     },
@@ -153,6 +154,7 @@ sub sort_files {
     opendir my $dh, $dir or return [500, "Can't opendir '$dir': $!"];
     my @files;
   GET_FILES: {
+        local $CWD = $dir;
       FILE:
         while (defined(my $e = readdir $dh)) {
             next if $e eq '.' || $e eq '..';
@@ -412,7 +414,6 @@ MARKDOWN
         sort_files(
             %args,
             by_field => 'size',
-            reverse => 1,
         );
     },
 );
@@ -458,6 +459,7 @@ MARKDOWN
         sort_files(
             %args,
             by_field => 'mtime',
+            reverse => 1,
         );
     },
 );
@@ -493,7 +495,6 @@ MARKDOWN
         sort_files(
             %args,
             by_field => 'mtime',
-            reverse => 1,
         );
     },
 );
@@ -579,7 +580,7 @@ App::FileSortUtils - Utilities related to sorting files in a directory
 
 =head1 VERSION
 
-This document describes version 0.002 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-10-29.
+This document describes version 0.003 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-10-30.
 
 =head1 DESCRIPTION
 
